pub struct RecordedDispatch {
pub node_id: NodeId,
pub inputs: Vec<(ResourceId, ResourceHandle)>,
pub outputs: Vec<(ResourceId, ResourceHandle)>,
}Expand description
One entry in a recording dispatcher’s tape. Captures everything a test might want to assert about a dispatch.
Fields
node_id: NodeIdinputs: Vec<(ResourceId, ResourceHandle)>outputs: Vec<(ResourceId, ResourceHandle)>Trait Implementations
Sourceimpl Clone for RecordedDispatch
impl Clone for RecordedDispatch
Sourcefn clone(&self) -> RecordedDispatch
fn clone(&self) -> RecordedDispatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecordedDispatch
impl Debug for RecordedDispatch
impl Eq for RecordedDispatch
Sourceimpl PartialEq for RecordedDispatch
impl PartialEq for RecordedDispatch
Sourcefn eq(&self, other: &RecordedDispatch) -> bool
fn eq(&self, other: &RecordedDispatch) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RecordedDispatch